
! ----------------------------------------------- acc2seismo_response
      subroutine acc2seismo_response(acc, nacc, dt, instr_type, 
     :           taper_beginning, taper_end,
     :           strip_pads,
     :           yout, nout)
     
! Compute instrument response in the frequency domain,
! using a poles and zeros representation of the instrument.

! instr_type = 'WA', 'WWSSN-SP', 'USGS-SP', 'PIDC-SP', ...


! Dates: 01/18/10 - Written by D. M. Boore, based on locut_fd
!        07/07/10 - poles_zeros_response has a logical input variable so that the
!                   phase can be set to zero for acausal filters (so that
!                   do not have to do two time domain filters)
!        07/19/10 - Call poles_zeros_values rather than assigning 
!                   values in this routine. Also, no longer use
!                   set_phase_to_0 as an argument in the call to
!                   poles_zeros_response.
 
      real acc(*), yout(*) 
      
      character instr_type*(*), strip_pads*1
      
      complex sp(20)
      character comments(200)*80
      
      
      complex CX(:), seismo_response
      allocatable :: cx 
      
      logical remove_mean_before, remove_mean_after,
     :  zcross_l, use_first, zcross_t, use_last, 
     :  replace_discarded_data_with_zeros
     
      call upstr(instr_type)
      call trim_c(instr_type,nc_instr_type)
      
      call poles_zeros_values(
     :      instr_type(1:nc_instr_type), gain, fgain, nz, np, sp)

! Determine factor to give proper gain 

      dum = 1.0
        
      idva = 2
      call poles_zeros_response(fgain, dum, nz, np, sp, idva, 
     :                              ampnorm, phase)
      gainfactor = gain/ampnorm
        
! Fill output array with input array:

      do i = 1, nacc
        yout(i) = acc(i)
      end do
      
* GET NPW2:      
      
      signnpw2 = +1.0
      call get_npw2(nacc,signnpw2,npw2) 
! DEBUG
!      write(*,*) ' In acc2seismo_response, after call to '//
!     :           'get_npw2, nacc, npw2 = ', nacc, npw2
! DEBUG
* sample rate and frequency spacing:

      sps = 1.0 / dt
      df_fft = sps/ float(npw2)

      npw2d2 = npw2 / 2

* Taper and add zeros:

      nzpad = npw2 - nacc      
      nlz = nzpad/2      
      ntz = nzpad - nlz

      remove_mean_before = .false.
      remove_mean_after = .false.
      zcross_l = .false.
      use_first = .false.
      zcross_t = .false.
      use_last = .false. 
      replace_discarded_data_with_zeros = .true.
      comments = ' '
      ncomments = 0      

      call smcpadf(yout, nacc, sps, nlz, ntz, 
     :  replace_discarded_data_with_zeros, 
     :  taper_beginning, taper_end, 
     :  nout, izcl, izct, 
     :  remove_mean_before, remove_mean_after, 
     :  zcross_l, use_first, zcross_t, use_last,
     :  comments, ncomments)  
     
      if (nout /= npw2) then
        write(*,*) ' ERROR: nout = ', nout,'; /= npw2 = ', npw2
        stop
      end if      

* Allocate and initialize working array
      
      n_alloc = npw2
      allocate( cx(n_alloc) )
      
      cx = cmplx(0.0,0.0)
      
c Fill working complex array

      do j = 1, npw2   
        cx(j)=cmplx(yout(j), 0.0)
      end do

c     FFT to get spectrum

      call fork(npw2,cx,-1.0)

      do j = 1, npw2d2
* Apply filter
        f = float(j-1)*df_fft
      idva = 2
        call poles_zeros_response(f, gainfactor, nz, np, sp, idva, 
     :                              amp, phase)
      if (instr_type(1:nc_instr_type) == 'PIDC-SP') then
          phase = 0.0
        end if
        seismo_response = cmplx(amp*cos(phase), amp*sin(phase))
        cx(j) = seismo_response * cx(j)
      end do
* Set Nyquist value to 0.0
      cx(npw2d2+1) = 0.0
* Fill in other half of array (for a real output)
      do j = 2, npw2d2
        cx(npw2-j+2) = conjg(cx(j))
      end do
      
* Go back to time domain:

      call fork(npw2,cx,+1.0)
      
      if (strip_pads == 'Y') then
        nstartm1 = nlz
        nout = nacc      
      else if (strip_pads == 'N') then 
        nstartm1 = 0
        nout = npw2
      else
        write(*,*) ' strip_pads = '//strip_pads//
     :             '-- not Y or N; QUITTING!'
        stop
      end if

      do j = 1, nout
        yout(j) = real(cx(j+nstartm1))  ! no scaling is needed with FORK
      end do
      
      deallocate(cx)

      return
      end
! ----------------------------------------------- acc2seismo_response

