* ----------------------------------- BEGIN BJF94V30Amp -------------------
      subroutine BJF94V30Amp(per, v30, bv, va, amp)

* Returns the BJF94 amplification for a specified V30 and period, using the cubic
* equations in Table 8 of BJF94 (for 5% damping and random component). 
* The value for per = 0.1 is used for all smaller periods and the per=2.0 value 
* is used for periods longer than 2.0 sec (in an earlier version I used
* per = 1.0).  Note that the latter is
* conservative; we expect the amplifications to reach unity for long enough
* periods (at least for Fourier spectra, what about for response spectra?)

* PGA corresponds to PER = 0.0

* Dates: 03/01/05 - Written by D. Boore, based on BJFV1V2F.FOR
*        07/04/05 - Have to trap for per < 0 (pgv, in some applications),
*                   in which case use amps for per = 0.5 (as suggested
*                   by Bommer...)
 
      real per, v30, bv, va, amp
      real cbv(0:3), cva(0:3)
      
      cbv(0) = -0.21172
      cbv(1) =  0.06619
      cbv(2) = -1.35085
      cbv(3) =  0.79809
      nc_bv = 4
      
      cva(0) =  3.04586
      cva(1) =  1.69975
      cva(2) = -2.97445
      cva(3) =  1.37668
      nc_va = 4
 
      if(per .eq. 0.0) then
        bv = -0.371
        va = 1396.0
      else
        if (per .lt. 0.0) then
          t = 0.5
        else if (per .gt. 0.0 .and. per .lt. 0.1) then
          t = 0.1
        else if (per .gt. 2.0) then
          t = 2.0
        else
          t = per
        end if
        bv = cubic(t, cbv, nc_bv)
        va = 10.0**cubic(t, cva, nc_va)          
      end if

      amp = 10.0**(bv*alog10(v30/va))
 
      return
      end

      function cubic(t, c, nc)
      
      real t, x, cubic
      integer nc, i
      real c(0:*)
      
      x = alog10(t/0.1)
      
      cubic = 0.0
      
      do i = 0, nc-1
        cubic = cubic + c(i)*x**float(i)
      end do
      
      return
      end
* ----------------------------------- END BJF94v30amp -------------------

         

