      Subroutine Envelope_SR(y, dt, npw2, nsmooth_phd,
     :                       envelope, freq_inst)

* Computes the Hilbert tranform of y and uses it to compute the
* envelope and instantaneous frequency

* I ran into an invalid argument in ATAN2 message while testing the routine,
* and because I do not have time to track this down (are both arguments
* 0.0?), and because the instantaneous frequency is actually the time 
* derivative of the phase of the analytical signal (which either requires 
* unwrapping the phase or using Norm Abrahamson's trick--- see program
* ampphphd.for), I've deleted the freq_inst part of the calculations.

* Some references:

* Farnbach, J.S. (1975). The complex envelope in seismic signal analysis, 
* BSSA 65, 951--962. 
* He states that the factor of 2 is applied for i = 2...npw2/2 (his indices 
* start at 0, I've added 1), which is different than the next reference:

* Mitra, S.K. (2001). Digital Signal Processing, McGraw-Hill, New York.
* He gives an algorithm on p. 794 (eq. 11.81), which is the one I've used here
* (the factor of 2 is applied from 0 frequency to just less than Nyquist).

* Need to include fork.

* Dates: 06/19/02 - Written by D. Boore.  Added "_SR" (meaning "SubRoutine")
*                   to name so that it would not be confused with the array 
*                   "envelope".
*        06/20/02 - Now call ampphphd, which hopefully computes the
*                   instantaneous frequency properly.        
*        07/14/02 - Allow smoothing of instantaneous frequency (prompted
*                   by Claerbout's notes on his web site)

      real y(*), envelope(*), freq_inst(*)
      logical calc_phd, apply_afact

      real phs(:)
      complex work(:)
      allocatable :: phs, work

      allocate (phs(npw2),work(npw2))

      nnyq = npw2/2 + 1
      df = 1.0/(dt * float(npw2))

      do i = 1, npw2
        work(i) = cmplx(y(i), 0.0)
      end do

      call fork(npw2, work, -1.0)

      do i = nnyq , npw2
        work(i) = 0.0
      end do

      do i = 1, nnyq - 1
        work(i) = 2.0*work(i)
      end do

      sign = +1.0
      calc_phd = .true.
      apply_afact = .false.
      call ampphphd(work, df, npw2, 
     :  envelope, phs, freq_inst, calc_phd, nsmooth_phd,
     :  apply_afact, dt_fft, sign)
! don't care about phase in this application  


*      call fork(npw2, work, +1.0)

*      do i = 1, npw2
*        envelope(i) = cabs(work(i))
*        freq_inst(i) = atan2(aimag(work(i)),real(work(i)))
*        freq_inst(i) = 0.0
*      end do

      deallocate (phs, work)

      return
      end

      