
! -------------------------------------------------------------------- FILTER
      subroutine filter(a, npts, dt, flc, nroll_lc, icaus_lc,
     :                  fhc, nroll_hc, icaus_hc, icaus_bn, d4notch, 
     :                  filter_type, nc_filter_type)

! Butterworth filter time series stored in 'a', according to the following:
! if fhc = 0 = flc       : no filtering
! if fhc = 0             : low-cut filter
! if flc = 0             : high-cut filter
! if neither flc, fhc = 0: band-pass filter
! if flc = fhc /= 0, a notch filter, where the width parameter d is given by real(nslope_lc)*10**(-real(nslope_hc))

! "bn" in "icaus_bn" means "Band" "Notch"; icaus_bn = 1 for a band or notch filter
! only if icaus_lc = icaus_hc = 1.

!
! Dates: 09/11/00 - Written by D. Boore
!        02/04/01 - Added separate nroll for lc and hc filters; for
!                   the bandpass filter the max of nroll_lc and nroll_hc 
!                   is used.  In the future, the bandpass subroutine may be 
!                   changed to allow for separate rolloffs at low and high
!                   frequencies.
!        02/20/10 - Added notch filter, and the d parameter for this filter
!        07/11/17 - Allow the low- and high-cut filters to be either causal or acausal, independently
!                   (previously they had to both be one or the other).
!        07/13/17 - Change input parameters (determine filter type in calling program)
      
      real a(*)
      character filter_type*(*)

      if (filter_type(1:nc_filter_type) == 'NF') then
        return
      else if (filter_type(1:nc_filter_type) == 'LC') then
        call locut(a, npts, flc, dt, nroll_lc, icaus_lc)
      else if (filter_type(1:nc_filter_type) == 'HC') then
        call hicut(a, npts, fhc, dt, nroll_hc, icaus_hc)
      else if (filter_type(1:nc_filter_type) == 'LCHC') then
        call locut(a, npts, flc, dt, nroll_lc, icaus_lc)
        call hicut(a, npts, fhc, dt, nroll_hc, icaus_hc)
      else if (filter_type(1:nc_filter_type) == 'BAND') then
        nroll_bp = max0(nroll_lc, nroll_hc)
        call band(a, npts, flc, fhc, dt, nroll_bp, icaus_bn)  
      else if (filter_type(1:nc_filter_type) == 'NOTCH') then
        call notch(a, npts, flc, dt, d4notch, icaus_bn)
      else
        write(*,'(a)') ' In filter, unknown filter type; quitting!!! '
        stop
      end if

      return
      end
! -------------------------------------------------------------------- FILTER    
