
! ----------------------------------------------- poles_zeros_values
      subroutine poles_zeros_values(
     :      instr_type, gain, fgain, nz, np, sp)

! Returns poles and zeros for common instrument types.
! The response is relative to displacement, for 
! velocity and acceleration response reduce nz by 1 and 2, respectively.

! To obtain the specified gain at f-fgain, call poles_zeros_response
! with a gain of 1.0 and f=fgain.  Let the output be response_1.  Then
! call poles_zeros_response again with a gain of gain/response_1.

! instr_type = 'WA', 'WWSSN-SP', 'USGS-SP', 'PIDC-SP', ...

! Dates: 07/07/10 - Written by D. M. Boore, based on acc2seismo_response
 
      complex sp(*) 
      
      character instr_type*(*), work_c*100
      
      work_c = ' '
      work_c = instr_type      
      call upstr(work_c)
      call trim_c(work_c,nc_work_c)
      
      select case(work_c(1:nc_work_c))
      
      case('WA')
      
! gain from Uhrhammer, R.A. and E.R. Collins (1990). Synthesis of Wood-
! Anderson seismograms from broadband digital records, \bssa {\bf 80},
! 702--716. (V = 2080$, T_0 = 0.8 (f_0 = 1/0.8 = 1.25), and \eta = 0.69).
!
! poles and zeros from above values of f_o and eta, using these relations:
!       2*pi*f_0 = sqrt(sp(1)**2 + sp(2)**2)
!       eta = abs(sp(1))/(2*pi*f_0)
      
        gain = 2080.0     
        fgain = 0.01    
        nz = 2
        np = 2
        sp(1) = cmplx( -5.41925, -5.68479)  
        sp(2) = cmplx( -5.41925, +5.68479)  
!        sp(1) = cmplx( -5.49779, -5.60886) ! standard_tab.doc (provided by
!        sp(2) = cmplx( -5.49779, +5.60886) ! Jim Dewey) containing notes from 
                                            ! Charles R. Hutt, 1 December 2006
      case('WWSSN-SP')      

! values from standard_tab.doc (provided by
! Jim Dewey) containing notes from 
! Charles R. Hutt, 1 December 2006

        gain = 1.0
        fgain = 1.0
        nz = 3
        np = 5
        sp(1) = cmplx( -3.72500, -6.22000)
        sp(2) = cmplx( -3.72500, +6.22000)
        sp(3) = cmplx( -5.61200, +0.00000)
        sp(4) = cmplx(-13.24000, +0.00000)
        sp(5) = cmplx(-21.08000, +0.00000)
        
      case('USGS-SP')      

! values from esupplement (Appendix 1) to Granville et al (BSSA 95, 1809-1824)
        gain = 1.0
        fgain = 1.0
        nz = 5  ! Granville et al specify 4 zeros for velocity)
        np = 8
        sp(1) = cmplx( -2.22144, +2.22144)
        sp(2) = cmplx( -2.22144, -2.22144)
        sp(3) = cmplx( -4.66503, +4.66503)
        sp(4) = cmplx( -4.66503, -4.66503)
        sp(5) = cmplx( -11.7736, +11.7736)
        sp(6) = cmplx( -11.7736, -11.7736)
        sp(7) = cmplx( -28.8787, +28.8787)
        sp(8) = cmplx( -28.8787, -28.8787)
         
      case('PIDC-SP')      

! values from esupplement (Appendix 2) to Granville et al (BSSA 95, 1809-1824)
        gain = 1.0
        fgain = 1.0
        nz = 7  ! Granville et al specify 6 zeros for velocity)
        np = 12
        sp(1) = cmplx( -5.02655, +0.00000)
        sp(2) = cmplx( -2.51327, +4.35312)
        sp(3) = cmplx( -2.51327, -4.35312)
        sp(4) = cmplx( -28.2743, +0.00000)
        sp(5) = cmplx( -14.1372, -24.4863)
        sp(6) = cmplx( -14.1372, +24.4863)
! Complete response is acausal, obtained by filtering twice; thus the poles and zeros
! are repeated. BUT NOTE: This does not give zero phase shift!  I need to
! use complex conjugates of something. A simple way to do this is set the
! phase to 0.0 in the calling program.
        sp(7) = cmplx( -5.02655, +0.00000)
        sp(8) = cmplx( -2.51327, +4.35312)
        sp(9) = cmplx( -2.51327, -4.35312)
        sp(10) = cmplx( -28.2743, +0.00000)
        sp(11) = cmplx( -14.1372, -24.4863)
        sp(12) = cmplx( -14.1372, +24.4863)

      case default
      
        write(*,*) ' ERROR: instr_type = '//
     :               work_c(1:nc_work_c)//
     :             ' not recognized; QUITTING!'
        stop
     
      end select

      return
      end
! ----------------------------------------------- poles_zeros_values
