*------------------   Begin rs2write  ----------------------------------
      subroutine rs2write(f_out, 
     :        damp, ndamp, per, nper, rd, rv, aa, 
     :        char_head, int_head, real_head, comments, 
     :        itflag, tprd, tprv, tpaa)

*  Writes response spectra in smc rs2 format

* The arrays char_head, int_head, real_head must be dimensioned
* by the calling program as follows:
*
*      character char_head(11)*80, comments(N)*80 ! see "N" below
*      integer int_head(48)
*      real real_head(50)
*      real rd(100,5), rv(100,5), aa(100,5)
*      real tprd(100,5), tprv(100,5), tpaa(100,5)

* Note that 
*      int_head(17) = npts
*      real_head(2) = sps
*      int_head(16) = ncomments (dimension array "comments" accordingly
*                                so that N is a number > = ncomments)
*      I have found that if no comments are included, BAP cannot process
*      the resulting file.  For this reason, be sure that at least one comment
*      is included (ncomments = 1, comments(1) = '|').
*
* default values for int_head = -32768
*                    real_head = 1.7e+38

* Dates: 02/06/01 - written by D. Boore, based on smcwrite.for
*        03/23/01 - renamed from smcwrtrs.for
*        05/25/01 - write times of peak response if itflag = 1

      real real_head(*)
      integer int_head(*)
      character*80 char_head(*), comments(*)
      character f_out*(*)
      real damp(*), per(*)
      real rd(100,5), rv(100,5), aa(100,5)
      real tprd(100,5), tprv(100,5), tpaa(100,5)

      twopi = 2.0*4.0*atan(1.0)

* Open output file:
      call get_lun(nu_out)
      open(unit=nu_out, file=f_out, status='unknown')

* Write name to screen:
      write(*,'(2x,a)') ' Output file name: ', f_out

* Write headers:

* First write the 11 lines of comments:

      char_head(1) = ' '
      char_head(1) = '5 RESPONSE SPECTRA'

      do i = 1, 11
        write(nu_out,'(a)') char_head(i)
      end do
          
      write(nu_out, '(8I10)') (int_head(i), i = 1, 48)

      write(nu_out, '(5e15.7)') (real_head(i), i = 1, 50)


      if (int_head(16) .gt. 0) then
        do i = 1, int_head(16)
          write(nu_out,'(a)') comments(i)
        end do
      end if
          
      write(nu_out,'(3(i2,a15))') 1,'cm', 1,'cm/sec', 1,'cm/sec/sec'

      write(nu_out,'(3i5)') ndamp, nper, itflag
      write(nu_out,'(5(4x,e11.5))') (damp(i),i=1, ndamp)
      write(nu_out,'(7e11.4)') (per(i),i=1, nper)

      do ii = 1, ndamp

        write(nu_out,'(a,f4.2,a)') 
     :   'Relative Displacement Response Spectrum at ', damp(ii),
     :   ' Damping'
        write(nu_out,'(7e11.4)') (rd(i,ii),i=1,nper)

        write(nu_out,'(a,f4.2,a)') 
     :   'Relative Velocity Response Spectrum at ', damp(ii),
     :   ' Damping'
        write(nu_out,'(7e11.4)') (rv(i,ii),i=1,nper)

        write(nu_out,'(a,f4.2,a)') 
     :   'Pseudo-Velocity Response Spectrum at ', damp(ii),
     :   ' Damping'
        write(nu_out,'(7e11.4)') ((twopi/per(i))*rd(i,ii),i=1,nper)

        write(nu_out,'(a,f4.2,a)') 
     :   'Absolute Acceleration Response Spectrum at ', damp(ii),
     :   ' Damping'
        write(nu_out,'(6e13.6)') (aa(i,ii),i=1,nper)

        if (itflag .eq. 1) then
          write(nu_out,'(a,f4.2,a)') 
     :       'Times of Maximum Response Relative Displacement at ', 
     :        damp(ii), ' Damping'
          write(nu_out,'(7e11.4)') (tprd(i,ii),i=1,nper)
          write(nu_out,'(a,f4.2,a)') 
     :       'Times of Maximum Response Relative Velocity at ', 
     :        damp(ii), ' Damping'
          write(nu_out,'(7e11.4)') (tprv(i,ii),i=1,nper)
          write(nu_out,'(a,f4.2,a)') 
     :       'Times of Maximum Response Absolute Acceleration at ', 
     :        damp(ii), ' Damping'
          write(nu_out,'(7e11.4)') (tpaa(i,ii),i=1,nper)
        end if

      end do

* That should be it; close the output file.

      close(unit=nu_out)

      return
      end
*------------------   End rs2write   ----------------------------------

