
! ----------------------------------------------------------------- begin RS_Calc
      subroutine rs_calc(acc, na, omega, damp, dt,
     :                   v0, d0, use_straightline_interp, rd, rv, aa)
        
!-----------------------------------------------------------------------
! This version does not return response time series.

! NOTE: "interp_acc" in the name of the previous version (see below)
! refers to the straightline interpolation
! done in subroutine icmpmx. The name was chosen before the sinc interpolation
! (Boore and Goulet) was used in computing response spectra (in smc2rs, as revised in
! February 2018) and RotDxx (in smc2psa_rot_gmrot_interp_acc_rot_osc_ts.for).
! sinc interpolation is accomplished by first interpolating a time series
! using interpolate_time_series_using_fork, and then passing that interpolated
! time series into rs_calc.  This is done in smc2rs.for.


! Dates: 02/09/18 - A revised version of rscalc_interp_acc.for; I intend for this 
!                   subroutine to be the only one called by other programs.  I added
!                   a variable to skip the straightline interpolation if desired
!                   (this interpolation is probably not needed if sinc interpolation
!                   has been used to resample the original time series with more sps),
!                   and I include the subroutines rdrvaa and icmpmx via include statements.
!        02/27/18 - Correct error in assigning skip_straightline_interp in smc2rs (it
!                   was set to T when the input from the control file asking
!                   if linear interpolation was to be used was set to Y). The logical 
!                   way to do this is to change skip_straightline_interp to use_straightline_interp.
!                   This requires changes to a number of routines that use rs_calc, but
!                   is the right thing to do.
!        08/09/18 - No longer bring in rdrvaa and icmpmx using an include statement, because 
!                   this is a problem in make_td_subs_file.bat.
!                 - I decide not to do this, because it will have reverberations when compiling
!                   various programs in \forprogs\.  Instead, I added a comment that
!                   SMSIM and EXSIM users should edit the include statement as needed.
!                   


      implicit none

      real(4) :: acc(*), omega, damp, dt, 
     :       rd, rv, aa, d0, v0 
      
      integer :: na, kg, kug, npr
      
      logical use_straightline_interp


      real(8) :: ug(:), pr, damp_dble, dt_dble, z(3)

      real(8) :: w, twopi
      
      allocatable :: ug
      
      integer :: i, nn

      dt_dble = dble(dt)
      damp_dble = dble(damp)
      
      kg = na
      
      allocate(ug(na))

          do i=1,kg
            ug(i) = dble(acc(i))
          enddo
!...
!... Compute response spectra
!...
           kug=kg-1
           
      w = dble(omega)
      
      twopi = 4.0d0*dasin(1.0d0)
      
      pr = twopi/w

      if (use_straightline_interp) then
        if(dt_dble == 0.0d0 .or. pr < 10.0d0*dt_dble) then
          call icmpmx(kug, ug, dt_dble, pr, w, damp_dble, z)
          rd = sngl(z(1))
          rv = sngl(z(2))
          aa = sngl(z(3))
        else
          call rdrvaa(acc,kg,omega,damp,dt,rd,rv,aa, d0, v0)
        endif
      else
        call rdrvaa(acc,kg,omega,damp,dt,rd,rv,aa, d0, v0)
      end if
            
      deallocate(ug)

      return
      end

      include 'icmpmx.for'
      include 'rdrvaa.for'

  
!      include '\forprogs\icmpmx.for'
!      include '\forprogs\rdrvaa.for'

! NOTE: users of my program might need to edit the include statement to make sure that it 
! points to the folder with the subroutines, or comment out these lines if the subroutines
! are included in the subroutine file, such as in td_subs.for for SMSIM

! I think a work around is to not specify \forprogs and copy in icmpmx and rdrvaa into the SMSIM root when
! running \smsim\make_td_subs_file.bat

! ----------------------------------------------------------------- end RS_Calc

 


