
! ---------------------------- BEGIN SELECT_SUBSETS_FOR_ROTATIONS -------------------
      subroutine select_subsets_for_rotations(
     :  y1_in, y2_in, n_in, dt, fraction,
     :  y1_out, y2_out, t_out, n_out,
     :  alevel)
     
! Implement Norm Abrahamson's algorithm (with my correction) to speed up computations:  
! save y1, y2 for times i for which 
! sqrt(y1_in(i)**2+y2_in(i)**2) > fraction*min(abs(y1(all times), abs(y2(all times))).
! Norm used fraction = 2/3 (theoretically, it could have been 1/sqrt(2)).    

! The larger the value of fraction, the smaller the output time series
! fraction = 0.0 will return all of the input time series.   
! This meaning of "fraction" may be confusing, as it might be natural to think that 
! the larger the fraction, the more of the oscillator time series will be rotated.  
! But it is just the opposite.  Fraction is used in setting the level "alevel" above 
! which the subset of the oscillator time series is chosen, according to
!               alevel = fraction*amin1(peak_y1, peak_y2)


! Dates: 09/23/12 - Written by D. M. Boore
!        09/26/12 - The algorithm did not work for a few of the test cases, so I am trying 
!                   a new algorithm.


      real y1_in(*), y2_in(*), dt, y1_out(*), y2_out(*), t_out(*),
     :     fraction
      
      integer n_in, n_out
      
!Find overall absolute maxima

      nstrt = 1
      ninc = 1
      call abs_mnmaxidx(y1_in, nstrt, n_in, ninc,
     :                  y1min, y1max, indx_min, indx_max, peak_y1) 
      call abs_mnmaxidx(y2_in, nstrt, n_in, ninc,
     :                  y2min, y2max, indx_min, indx_max, peak_y2) 
     
      alevel = fraction*amin1(peak_y1, peak_y2)

!DEBUG
!      print *,' y1min, y1max, peak_y1 =', y1min, y1max, peak_y1
!      print *,' y2min, y2max, peak_y2 =', y2min, y2max, peak_y2
!      print *,' fraction, alevel =', fraction, alevel
!DEBUG

      n_out = 0
      
      DO i = 1, n_in
      
!        if (abs(y1_in(i)) >= alevel .or. abs(y2_in(i)) >= alevel) then
        if (sqrt(y1_in(i)**2+y2_in(i)**2) >= alevel) then
          n_out = n_out + 1
          y1_out(n_out) = y1_in(i)
          y2_out(n_out) = y2_in(i)
          t_out(n_out) = real(i-1)*dt
          cycle
        end if
      
      END DO
      
      return
      end
! ---------------------------- END SELECT_SUBSETS_FOR_ROTATIONS -------------------

      
!      include '\forprogs\abs_mnmaxidx.for'  ! Included in smc2psa_util_subs
       
      
      
      